<template>
  <el-row>
    <el-col :span="22">
      <v-chart style="height:500px" :options="options" />
    </el-col>
  </el-row>
</template>

<script>
import ECharts from 'vue-echarts'
import { getQualityCheckRatePicture } from '@/api/quality/apply'
export default {
  name: 'rateChart',
  components: {
    'v-chart': ECharts
  },
  props: {
    paramObj: {
      type: Object,
      default: () => {}
    }
  },
  mounted() {
    getQualityCheckRatePicture(this.paramObj)
      .then((response) => {
        if (response.data && response.data.code === 0) {
          this.dataNumList = []
          this.dataNumRateList = []
          this.xAxisList = []

          response.data.data.forEach((item) => {
            if (item.chartType === '合格率') {
              this.dataNumRateList.push({
                value: item.qualityValue ? item.qualityValue : 0,
                name: item.name
              })

              if (
                this.xAxisList.findIndex((val) => val === item.qualityDate) ===
                -1
              ) {
                this.xAxisList.push(item.qualityDate)
              }
              if (this.allGX.findIndex((val) => val === item.name) === -1) {
                this.allGX.push(item.name)
              }
            }
          })
          console.log(this.allGX)
          if (this.xAxisList.length < 4) {
            this.options.dataZoom[0].show = false
            this.options.dataZoom[0].end = 100
            this.options.dataZoom[1].end = 100
          } else {
            this.options.dataZoom[0].show = true
            this.options.dataZoom[0].end = 50
            this.options.dataZoom[1].end = 50
          }
          this.options.xAxis[0].data = this.xAxisList
          //   this.options.series[0].data = this.dataNumRateList

          this.allGX.forEach((gx) => {
            const dataNum = []
            for (let i = 0; i < this.xAxisList.length; i++) {
              const element = response.data.data.find((val) => {
                return (
                  val.qualityDate === this.xAxisList[i] &&
                  val.chartType === '产量' &&
                  gx === val.name
                )
              })
              const rate = response.data.data.find((val) => {
                return (
                  val.qualityDate === this.xAxisList[i] &&
                  val.chartType === '合格率' &&
                  gx === val.name
                )
              })
              if (element) {
                dataNum.push({
                  value: element.qualityValue,
                  custom: rate.qualityValue
                })
              } else {
                dataNum.push('-')
              }
            }
            this.options.series.push({
              name: gx,
              type: 'bar',
              barWidth: 20,
              emphasis: {
                focus: 'series'
              },
              //   barGap: 0,
              label: {
                show: true,
                position: 'top',
                distance: 15,
                verticalAlign: 'middle',
                formatter: function(val) {
                  return val.data.value + '\n' + val.data.custom + '%'
                },
                fontSize: 9,
                color: '#000'
              },
              //   itemStyle: {
              //     normal: {
              //       label: {
              //         show: true,
              //         position: 'top',
              //         textStyle: {
              //           color: 'black',
              //           fontSize: 9
              //         }
              //       }
              //     }
              //   },
              data: dataNum
            })
          })
        }
      })
      .catch(() => {})
  },
  data() {
    return {
      colorRecord: {},
      colorIndex: 0,
      allGX: [],
      isUsed: {},
      dataNumList: [],
      dataNumRateList: [],
      xAxisList: [],

      options: {
        // tooltip: {
        //   trigger: 'axis',
        //   axisPointer: {
        //     type: 'cross',
        //     label: {
        //       backgroundColor: '#6a7985'
        //     }
        //   }
        // },
        tooltip: {
          trigger: 'axis',
          axisPointer: {
            type: 'shadow'
          },
          formatter: function(params) {
            let str = params[0].axisValue + '<br />'
            params.forEach((item) => {
              if (item.data.value) {
                str +=
                  '<span style="display:inline-block;margin-right:5px;border-radius:50%;width:10px;height:10px;left:5px;background-color:' +
                  item.color +
                  '"></span>' +
                  item.seriesName +
                  ' : ' +
                  (item.data.value
                    ? item.data.value +
                      ('  合格率:' +
                        (item.data.custom ? item.data.custom + '%' : '-'))
                    : '-') +
                  '<br />'
              }
            })
            return str
          }
        },
        legend: {
          orient: 'vertical',
          right: 0,
          y: 'center',

          type: 'scroll'
        },
        grid: {
          //   left: '0',
          //   right: '0',
          //   top: '15%',
          containLabel: true
        },
        dataZoom: [
          {
            show: false, // 是否显示下方滚动条
            realtime: true,
            start: 0, // 显示数据开始位置
            end: 50 // 显示数据结束位置
          },
          {
            type: 'inside',
            realtime: true,
            start: 0,
            end: 50,
            zoomLock: true
          }
        ],

        xAxis: [
          {
            type: 'category',
            data: [],
            axisLabel: {
              //   rotate: 45,
              textStyle: {
                color: '#000',
                fontSize: 14
              }
            },
            axisPointer: {
              type: 'shadow'
            }
          }
        ],
        yAxis: [
          {
            type: 'value',
            name: '合格数量',
            min: 0,
            splitLine: false
          },
          {
            type: 'value',
            name: '合格率',
            splitLine: false,
            min: 0,
            max: 100,
            axisLabel: {
              formatter: '{value} %'
            }
          }
        ],
        series: [
          //   {
          //     name: '合格率',
          //     type: 'line',
          //     yAxisIndex: 1,
          //     itemStyle: {
          //       normal: {
          //         label: {
          //           show: false,
          //           position: 'right',
          //           textStyle: {
          //             color: 'black',
          //             fontSize: 12
          //           }
          //         },
          //         color: '#ff0000'
          //       }
          //     },
          //     data: []
          //   }
        ]
      }
    }
  }
}
</script>

<style scoped>
div >>> .echarts {
  width: 100%;
}
</style>
